@@ -2,16 +2,22 @@ import functools
 
 import regex
 
+from animdl.utils import optopt
+
 from ....config import ANIMEPAHE
 from ...helpers import construct_site_based_regex
 from .inner import get_animepahe_url
 
 REGEX = construct_site_based_regex(ANIMEPAHE, extra_regex=r"/(anime|play)/([^?&/]+)")
 
-ID_RE = regex.compile(r'let id = "(.+?)"')
-KWIK_RE = regex.compile(r"Plyr\|(.+?)'")
+ID_RE = optopt.regexlib.compile(r'let id = "(.+?)"')
+KWIK_RE = optopt.regexlib.compile(r"Plyr\|(.+?)'")
 
-TITLES_REGEX = regex.compile(r"<h1>(.+?)</h1>")
+STREAMS_REGEX = optopt.regexlib.compile(
+    r'<a href="(?P<url>.+?)" .+? class="dropdown-item">.+? (?P<resolution>\d+)p.+?</a>'
+)
+
+TITLES_REGEX = optopt.regexlib.compile(r"<h1>(.+?)</h1>")
 
 
 def get_streams_from_embed_url(session, embed_uri):
@@ -22,18 +28,15 @@ def get_streams_from_embed_url(session, embed_uri):
 
 
 def iter_stream_url_from_stream_session(session, release_id, stream_session):
-
     stream_url_data = session.get(
-        ANIMEPAHE + "api",
-        params={"m": "links", "id": release_id, "session": stream_session, "p": "kwik"},
+        ANIMEPAHE + f"play/{release_id}/{stream_session}",
     )
 
-    for qualities in stream_url_data.json().get("data", []):
-        for quality, data in qualities.items():
-            yield {
-                "quality": quality,
-                "stream_url": get_animepahe_url(session, data["kwik_pahewin"]),
-            }
+    for url, resolution in STREAMS_REGEX.findall(stream_url_data.text):
+        yield {
+            "quality": int(resolution),
+            "stream_url": get_animepahe_url(session, url),
+        }
 
 
 def iter_episode_streams(session, release_id, per_page, episode_number):
@@ -49,13 +52,6 @@ def iter_episode_streams(session, release_id, per_page, episode_number):
     )
 
 
-def bypass_ddos_guard(session):
-    js_bypass_uri = regex.search(
-        r"'(.*?)'", session.get("https://check.ddos-guard.net/check.js").text
-    ).group(1)
-    session.cookies.update(session.get(ANIMEPAHE + js_bypass_uri).cookies)
-
-
 @functools.lru_cache()
 def fetch_session(session, release_id, *, page=None):
     return session.get(
